@@ -31,18 +31,13 @@ class CreateSlrAndSlsProjectRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_BusinessType(self): # String
-		return self.get_body_params().get('BusinessType')
-
-	def set_BusinessType(self, BusinessType):  # String
-		self.add_body_params('BusinessType', BusinessType)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
 	def get_Region(self): # String
 		return self.get_body_params().get('Region')
 
 	def set_Region(self, Region):  # String
 		self.add_body_params('Region', Region)
+	def get_BusinessType(self): # String
+		return self.get_body_params().get('BusinessType')
+
+	def set_BusinessType(self, BusinessType):  # String
+		self.add_body_params('BusinessType', BusinessType)
