@@ -36,23 +36,18 @@ class DescribeDcdnBgpTrafficDataRequest(RpcRequest):
 
 	def set_Isp(self, Isp):  # String
 		self.add_query_param('Isp', Isp)
-	def get_StartTime(self): # String
-		return self.get_query_params().get('StartTime')
-
-	def set_StartTime(self, StartTime):  # String
-		self.add_query_param('StartTime', StartTime)
 	def get_EndTime(self): # String
 		return self.get_query_params().get('EndTime')
 
 	def set_EndTime(self, EndTime):  # String
 		self.add_query_param('EndTime', EndTime)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
 	def get_Interval(self): # String
 		return self.get_query_params().get('Interval')
 
 	def set_Interval(self, Interval):  # String
 		self.add_query_param('Interval', Interval)
+	def get_StartTime(self): # String
+		return self.get_query_params().get('StartTime')
+
+	def set_StartTime(self, StartTime):  # String
+		self.add_query_param('StartTime', StartTime)
