@@ -25,38 +25,34 @@ class DescribeDcdnDomainConfigsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dcdn', '2018-01-15', 'DescribeDcdnDomainConfigs')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_FunctionNames(self):
+	def get_FunctionNames(self): # String
 		return self.get_query_params().get('FunctionNames')
 
-	def set_FunctionNames(self,FunctionNames):
-		self.add_query_param('FunctionNames',FunctionNames)
-
-	def get_DomainName(self):
-		return self.get_query_params().get('DomainName')
-
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_OwnerId(self):
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_SecurityToken(self):
+	def set_FunctionNames(self, FunctionNames):  # String
+		self.add_query_param('FunctionNames', FunctionNames)
+	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
+	def set_SecurityToken(self, SecurityToken):  # String
+		self.add_query_param('SecurityToken', SecurityToken)
+	def get_DomainName(self): # String
+		return self.get_query_params().get('DomainName')
 
-	def get_ConfigId(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_OwnerId(self): # Long
+		return self.get_query_params().get('OwnerId')
+
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_ConfigId(self): # String
 		return self.get_query_params().get('ConfigId')
 
-	def set_ConfigId(self,ConfigId):
-		self.add_query_param('ConfigId',ConfigId)
\ No newline at end of file
+	def set_ConfigId(self, ConfigId):  # String
+		self.add_query_param('ConfigId', ConfigId)
