@@ -31,21 +31,6 @@ class DescribeDcdnDomainIpaBpsDataRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_LocationNameEn(self): # String
-		return self.get_query_params().get('LocationNameEn')
-
-	def set_LocationNameEn(self, LocationNameEn):  # String
-		self.add_query_param('LocationNameEn', LocationNameEn)
-	def get_StartTime(self): # String
-		return self.get_query_params().get('StartTime')
-
-	def set_StartTime(self, StartTime):  # String
-		self.add_query_param('StartTime', StartTime)
-	def get_IspNameEn(self): # String
-		return self.get_query_params().get('IspNameEn')
-
-	def set_IspNameEn(self, IspNameEn):  # String
-		self.add_query_param('IspNameEn', IspNameEn)
 	def get_FixTimeGap(self): # String
 		return self.get_query_params().get('FixTimeGap')
 
@@ -66,13 +51,23 @@ class DescribeDcdnDomainIpaBpsDataRequest(RpcRequest):
 
 	def set_EndTime(self, EndTime):  # String
 		self.add_query_param('EndTime', EndTime)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
 	def get_Interval(self): # String
 		return self.get_query_params().get('Interval')
 
 	def set_Interval(self, Interval):  # String
 		self.add_query_param('Interval', Interval)
+	def get_LocationNameEn(self): # String
+		return self.get_query_params().get('LocationNameEn')
+
+	def set_LocationNameEn(self, LocationNameEn):  # String
+		self.add_query_param('LocationNameEn', LocationNameEn)
+	def get_StartTime(self): # String
+		return self.get_query_params().get('StartTime')
+
+	def set_StartTime(self, StartTime):  # String
+		self.add_query_param('StartTime', StartTime)
+	def get_IspNameEn(self): # String
+		return self.get_query_params().get('IspNameEn')
+
+	def set_IspNameEn(self, IspNameEn):  # String
+		self.add_query_param('IspNameEn', IspNameEn)
