@@ -36,13 +36,3 @@ class DescribeDcdnIpInfoRequest(RpcRequest):
 
 	def set_IP(self, IP):  # String
 		self.add_query_param('IP', IP)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
-	def get_SecurityToken(self): # String
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self, SecurityToken):  # String
-		self.add_query_param('SecurityToken', SecurityToken)
