@@ -36,8 +36,3 @@ class DescribeDcdnRefreshTaskByIdRequest(RpcRequest):
 
 	def set_TaskId(self, TaskId):  # String
 		self.add_query_param('TaskId', TaskId)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
