@@ -70,6 +70,11 @@ class DescribeDcdnUserDomainsRequest(RpcRequest):
 				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
 			if Tag[depth1].get('Key') is not None:
 				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
+	def get_WebSiteType(self): # String
+		return self.get_query_params().get('WebSiteType')
+
+	def set_WebSiteType(self, WebSiteType):  # String
+		self.add_query_param('WebSiteType', WebSiteType)
 	def get_Coverage(self): # String
 		return self.get_query_params().get('Coverage')
 
