@@ -36,11 +36,6 @@ class DescribeDcdnUserSecDropRequest(RpcRequest):
 
 	def set_Data(self, Data):  # String
 		self.add_query_param('Data', Data)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
 	def get_Metric(self): # String
 		return self.get_query_params().get('Metric')
 
