@@ -36,8 +36,3 @@ class DescribeDcdnWafPolicyRequest(RpcRequest):
 
 	def set_PolicyId(self, PolicyId):  # Long
 		self.add_query_param('PolicyId', PolicyId)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
