@@ -36,8 +36,3 @@ class DescribeDcdnWafScenesRequest(RpcRequest):
 
 	def set_DefenseScenes(self, DefenseScenes):  # String
 		self.add_query_param('DefenseScenes', DefenseScenes)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
