@@ -31,18 +31,13 @@ class DescribeRoutineCodeRevisionRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_SelectCodeRevision(self): # String
-		return self.get_body_params().get('SelectCodeRevision')
-
-	def set_SelectCodeRevision(self, SelectCodeRevision):  # String
-		self.add_body_params('SelectCodeRevision', SelectCodeRevision)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
 	def get_Name(self): # String
 		return self.get_body_params().get('Name')
 
 	def set_Name(self, Name):  # String
 		self.add_body_params('Name', Name)
+	def get_SelectCodeRevision(self): # String
+		return self.get_body_params().get('SelectCodeRevision')
+
+	def set_SelectCodeRevision(self, SelectCodeRevision):  # String
+		self.add_body_params('SelectCodeRevision', SelectCodeRevision)
