@@ -36,6 +36,11 @@ class ModifyDcdnWafPolicyDomainsRequest(RpcRequest):
 
 	def set_PolicyId(self, PolicyId):  # Long
 		self.add_body_params('PolicyId', PolicyId)
+	def get_Method(self): # Integer
+		return self.get_body_params().get('Method')
+
+	def set_Method(self, Method):  # Integer
+		self.add_body_params('Method', Method)
 	def get_BindDomains(self): # String
 		return self.get_body_params().get('BindDomains')
 
