@@ -31,6 +31,11 @@ class PublishRoutineCodeRevisionRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_Name(self): # String
+		return self.get_body_params().get('Name')
+
+	def set_Name(self, Name):  # String
+		self.add_body_params('Name', Name)
 	def get_SelectCodeRevision(self): # String
 		return self.get_body_params().get('SelectCodeRevision')
 
@@ -41,13 +46,3 @@ class PublishRoutineCodeRevisionRequest(RpcRequest):
 
 	def set_Envs(self, Envs):  # String
 		self.add_body_params('Envs', Envs)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
-	def get_Name(self): # String
-		return self.get_body_params().get('Name')
-
-	def set_Name(self, Name):  # String
-		self.add_body_params('Name', Name)
