@@ -31,23 +31,23 @@ class SetDcdnFullDomainsBlockIPRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_IPList(self): # String
-		return self.get_body_params().get('IPList')
-
-	def set_IPList(self, IPList):  # String
-		self.add_body_params('IPList', IPList)
 	def get_BlockInterval(self): # Integer
 		return self.get_body_params().get('BlockInterval')
 
 	def set_BlockInterval(self, BlockInterval):  # Integer
 		self.add_body_params('BlockInterval', BlockInterval)
+	def get_UpdateType(self): # String
+		return self.get_body_params().get('UpdateType')
+
+	def set_UpdateType(self, UpdateType):  # String
+		self.add_body_params('UpdateType', UpdateType)
 	def get_OperationType(self): # String
 		return self.get_body_params().get('OperationType')
 
 	def set_OperationType(self, OperationType):  # String
 		self.add_body_params('OperationType', OperationType)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
+	def get_IPList(self): # String
+		return self.get_body_params().get('IPList')
 
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
+	def set_IPList(self, IPList):  # String
+		self.add_body_params('IPList', IPList)
