@@ -31,18 +31,13 @@ class UpdateDcdnUserRealTimeDeliveryFieldRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_BusinessType(self): # String
-		return self.get_query_params().get('BusinessType')
-
-	def set_BusinessType(self, BusinessType):  # String
-		self.add_query_param('BusinessType', BusinessType)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
 	def get_Fields(self): # String
 		return self.get_query_params().get('Fields')
 
 	def set_Fields(self, Fields):  # String
 		self.add_query_param('Fields', Fields)
+	def get_BusinessType(self): # String
+		return self.get_query_params().get('BusinessType')
+
+	def set_BusinessType(self, BusinessType):  # String
+		self.add_query_param('BusinessType', BusinessType)
