@@ -36,11 +36,6 @@ class UploadStagingRoutineCodeRequest(RpcRequest):
 
 	def set_CodeDescription(self, CodeDescription):  # String
 		self.add_body_params('CodeDescription', CodeDescription)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
 	def get_Name(self): # String
 		return self.get_body_params().get('Name')
 
